@@ -12,7 +12,9 @@ from typing import Literal
 from tkdev.devicon import Icon_Empty
 from tkdev.devresize import DevResize
 from tkdev.devnet import WindowEffect
+from tkdev.devcore import DevAction, DevSysTray
 import warnings
+
 try:
     from deprecated.sphinx import deprecated
 except ImportError:
@@ -49,18 +51,26 @@ Dark = "dark"
 DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
+def UpGrade(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+    import os
+    import sys
+    if Basic:
+        print(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
+        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
+    else:
+        print(f"{sys.executable} -m pip install {Library} --upgrade")
+        os.system(f"{sys.executable} -m pip install {Library} --upgrade")
+
+
 def Install(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     import os
     import sys
     if Basic:
-        print(f"{sys.executable} -m pip install {Library} -i {Pypi}")
+        print(f"{sys.executable} -m pip install {Library}  -i {Pypi}")
         os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi}")
-        print(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
-        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
     else:
         print(f"{sys.executable} -m pip install {Library}")
         os.system(f"{sys.executable} -m pip install {Library}")
-        os.system(f"{sys.executable} -m pip install {Library} --upgrade")
 
 
 def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
@@ -74,6 +84,14 @@ def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
     Install("Deprecated", Basic=Basic, Pypi=Pypi)
 
 
+def UnInstall(Library):
+    import os
+    import sys
+    if Basic:
+        print(f"{sys.executable} -m pip uninstall {Library}")
+        os.system(f"{sys.executable} -m pip uninstall {Library} ")
+
+
 class AccentState(Enum):
     ACCENT_DISABLED = 0,
     ACCENT_ENABLE_GRADIENT = 1,
@@ -826,149 +844,6 @@ except NameError:
     pass
 
 
-@deprecated(version='2.3.8', reason="此组件已经启用，请改用DevHeaderBar组件")
-class DevTitleBar(tk.Frame):
-    def __init__(self, master: tk.Widget, iswindow: bool = True, window: tk.Tk = None, widget: tk.Widget = None,
-                 button_side: str = tk.RIGHT, background="#ffffff",
-                 close: bool = True, max: bool = True, min: bool = True, title: bool = True, title_label: str = "",
-                 title_bg="#ffffff", title_fg="#000000",
-                 close_bg="#ffffff", max_bg="#ffffff", min_bg="#ffffff", close_func=None,
-                 close_active_bg="#e81123", close_active_fg="#f5f5f5", max_active_bg="#c2c2c2", max_active_fg="#ffffff",
-                 min_active_bg="#c2c2c2", min_active_fg="#ffffff", minwindow_border_color="#35384b",
-                 minwindow_icon=None,
-                 close_fg="#000000", max_fg="#000000", min_fg="#000000"):
-        super(DevTitleBar, self).__init__(background=background, master=master)
-        self.widget = widget
-        self.button_side = button_side
-        self.title = title
-        self.title_label = title_label
-        self.title_bg = title_bg
-        self.title_fg = title_fg
-        self.close = close
-        self.close_bg = close_bg
-        self.close_fg = close_fg
-        self.close_active_bg = close_active_bg
-        self.close_active_fg = close_active_fg
-        self.close_func = close_func
-        self.max = max
-        self.max_bg = max_bg
-        self.max_fg = max_fg
-        self.max_active_bg = max_active_bg
-        self.max_active_fg = max_active_fg
-        self.min = min
-        self.min_bg = min_bg
-        self.min_fg = min_fg
-        self.min_active_bg = min_active_bg
-        self.min_active_fg = min_active_fg
-        self.minwindow_border_color = minwindow_border_color
-        self.minwindow_icon = minwindow_icon
-
-        self.ismax = False
-
-        if self.title:
-            self.add_title(title=self.title_label, title_bg=self.title_bg, title_fg=self.title_fg)
-        if self.close:
-            self.add_close(close_bg=self.close_bg, close_fg=self.close_fg, close_active_bg=self.close_active_bg,
-                           close_active_fg=self.close_active_fg, close_func=self.close_func)
-        if self.max:
-            self.add_max(max_bg=self.max_bg, max_fg=self.max_fg, max_active_bg=self.max_active_bg,
-                         max_active_fg=self.max_active_fg)
-        if self.min:
-            self.add_min(min_bg=self.min_bg, min_fg=self.min_fg, min_active_bg=self.min_active_bg,
-                         min_active_fg=self.min_active_fg)
-        self.widget = widget
-        DevDrag(self, self.widget)
-        self.window = window
-        self.iswindow = iswindow
-        if iswindow:
-            window_move(self, window)
-        if self.iswindow:
-
-            if self.close:
-                self.closebutton.configure(command=self.widget_close)
-            if self.max:
-                self.maxbutton.configure(command=self.widget_max)
-            if self.min:
-                self.minbutton.configure(command=self.widget_min)
-        else:
-            if self.close:
-                self.closebutton.configure(command=self.widget_close)
-            if self.max:
-                self.maxbutton.configure(command=self.widget_max)
-            if self.min:
-                self.minbutton.configure(command=self.widget_min)
-        self.bind("<Double-Button-1>", lambda evt: self.widget_max())
-
-    def add_title(self, title: str = "", title_bg="#ffffff", title_fg="#000000"):
-        self.title = tk.Label(self, text=title, background=title_bg, foreground=title_fg)
-        self.title.pack(fill=tk.X, side=tk.LEFT, padx=5)
-
-    def add_close(self, close_bg="#ffffff", close_fg="#000000", close_active_bg="#e81123", close_active_fg="#f5f5f5",
-                  close_func=None):
-        self.closebutton = tk.Button(self, text='×', borderwidth=0, background=close_bg, foreground=close_fg,
-                                     font=("微软雅黑", 13),
-                                     activebackground=close_active_bg, command=close_func,
-                                     activeforeground=close_active_fg)
-        self.closebutton.pack(fill=tk.Y, side=self.button_side, ipadx=5)
-
-    def add_max(self, max_bg="#ffffff", max_fg="#000000", max_active_bg="#c2c2c2", max_active_fg="#ffffff"):
-        self.maxbutton = tk.Button(self, text="▢", borderwidth=0, background=max_bg, foreground=max_fg,
-                                   font=("微软雅黑", 13),
-                                   activebackground=max_active_bg,
-                                   activeforeground=max_active_fg)
-        self.maxbutton.pack(fill=tk.Y, side=self.button_side, ipadx=5)
-
-    def add_min(self, min_bg="#ffffff", min_fg="#000000", min_active_bg="#c2c2c2", min_active_fg="#ffffff"):
-        self.minbutton = tk.Button(self, text="-", borderwidth=0, background=min_bg, foreground=min_fg,
-                                   font=("微软雅黑", 13),
-                                   activebackground=min_active_bg,
-                                   activeforeground=min_active_fg)
-        self.minbutton.pack(fill=tk.Y, side=self.button_side, ipadx=8)
-
-    def widget_close(self):
-        if self.iswindow:
-            self.window.destroy()
-        elif not self.iswindow:
-            self.widget.destroy()
-
-    def widget_max(self):
-        if self.iswindow:
-            if self.ismax:
-                self.window.state("normal")
-                self.ismax = False
-            elif not self.ismax:
-                self.window.state("zoomed")
-                self.ismax = True
-            self.window.update()
-        if not self.iswindow:
-            if self.ismax:
-                self.widget.place(width=self._width, height=self._height, x=self._x, y=self._y)
-                self.ismax = False
-            elif not self.ismax:
-                self._x = self.widget.winfo_x()
-                self._y = self.widget.winfo_y()
-                self._width = self.widget.winfo_width()
-                self._height = self.widget.winfo_height()
-                self.widget.place(width=self.widget.master.winfo_width(), height=self.widget.master.winfo_height(), x=0,
-                                  y=0)
-                self.widget.place(x=0, y=0)
-                self.ismax = True
-            self.widget.update()
-        self.update()
-
-    def widget_min(self):
-        if self.iswindow:
-            self.window.state("iconic")
-        elif not self.iswindow:
-            try:
-                self.widget.forget()
-            except tk.TclError:
-                pass
-
-    def show(self):
-        self.pack(fill=tk.X, side=tk.TOP)
-
-
 class DevToast(tk.Toplevel):
     def __init__(self, master: tk.Tk = None,
                  title: str = "Title", message: str = "Message", height: int = 80):
@@ -987,6 +862,37 @@ class DevToast(tk.Toplevel):
         self.after(5000, self.withdraw)
 
 
+class DevTabber(tk.Frame):
+    def __init__(self, master: tk.Widget):
+        super(DevTabber, self).__init__(master=master)
+        self.actions = {}
+        self.actions_button = {}
+
+    def add_action(self, name: str, action: DevAction, use_ttk: bool = False) -> tk.Widget:
+        self.actions[name] = action
+        if use_ttk:
+            self.actions_button[name] = ttk.Button(self, text=action.text, image=action.icon, command=action.command)
+        else:
+            self.actions_button[name] = tk.Button(self, text=action.text, image=action.icon,
+                                                  background=action.background, foreground=action.foreground,
+                                                  activebackground=action.active_background,
+                                                  activeforeground=action.active_foreground,
+                                                  command=action.command)
+        return self.actions_button[name]
+
+    def show(self):
+        self.pack(fill=tk.X, side=tk.BOTTOM)
+
+    def remove_action(self, name: str):
+        self.actions_button[name].forget()
+
+    def get_action(self, name: str):
+        return self.actions[name]
+
+    def get_action_button(self, name: str):
+        return self.actions_button[name]
+
+
 class DevWindow(tk.Tk):
     def __init__(self, title: str = ""):
         super(DevWindow, self).__init__()
@@ -1106,12 +1012,27 @@ class DevToplevel(tk.Toplevel, DevWindow):
 
 
 if __name__ == '__main__':
-    from tkdev import DevWindow, window_move
-    from tkinter import Frame
+    from win32gui import (GetParent, SetWindowLong, SetWindowPos, UpdateWindow, ReleaseCapture, SendMessage)
+    from win32con import (GWL_STYLE, WS_CAPTION, NULL, SWP_NOSIZE, SWP_NOMOVE, SWP_NOZORDER, SWP_DRAWFRAME,
+                          WM_SYSCOMMAND, SC_MOVE, HTCAPTION)
+    from tkinter import Tk
 
-    Install("cefpython3")
-    Window = DevWindow()
-    TitleBar = Frame(Window, height=35, background="#000000")
-    window_move(TitleBar, Window)
-    TitleBar.pack(fill="x")
+    Window = Tk()
+
+
+    def custom():
+        hWnd = GetParent(Window.winfo_id())
+        SetWindowLong(hWnd, GWL_STYLE, GetWindowLong(hWnd, GWL_STYLE) & ~WS_CAPTION)
+        SetWindowPos(hWnd, NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOMOVE | SWP_NOZORDER | SWP_DRAWFRAME)
+        UpdateWindow(hWnd)
+
+
+    def move(evt):
+        ReleaseCapture()
+        SendMessage(GetParent(Window.winfo_id()), WM_SYSCOMMAND,
+                    SC_MOVE + HTCAPTION, 0)
+
+
+    Window.bind("<B1-Motion>", move)
+    Window.after(100, custom)
     Window.mainloop()
\ No newline at end of file
